## Classes

<dl>
<dt><a href="#PublisherAPI">PublisherAPI</a></dt>
<dd></dd>
</dl>

## Typedefs

<dl>
<dt><a href="#AdBreak">AdBreak</a> : <code>Object</code></dt>
<dd><p>Definition of the upcoming ad slot.</p>
</dd>
<dt><a href="#EnvironmentVars">EnvironmentVars</a> : <code>Object</code></dt>
<dd><p>Used for passing implementation-specific runtime variables.</p>
</dd>
<dt><a href="#Wrapper">Wrapper</a> : <code>Array</code></dt>
<dd><p>List of URLs that have been requested during a chain of ad server requests.</p>
</dd>
<dt><a href="#UniversalAdID">UniversalAdID</a> : <code>Object</code></dt>
<dd><p>A unique creative ID for the ad across multiple systems.</p>
</dd>
<dt><a href="#AdInfo">AdInfo</a> : <code>Object</code></dt>
<dd><p>Collection of data that describes the current video ad.</p>
</dd>
<dt><a href="#CompanionAd">CompanionAd</a> : <code>Object</code></dt>
<dd><p>Secondary ads included in the VAST tag that accompany the video ad.</p>
</dd>
<dt><a href="#Extension">Extension</a> : <code>Object</code></dt>
<dd><p>Custom XML element that extends the video ad.</p>
</dd>
</dl>

<a name="PublisherAPI"></a>

## PublisherAPI
**Kind**: global class  

* [PublisherAPI](#PublisherAPI)
    * [new PublisherAPI(playerProxy, config)](#new_PublisherAPI_new)
    * [.adInfo](#PublisherAPI+adInfo) ⇒ <code>[AdInfo](#AdInfo)</code>
    * [.adInteractiveState](#PublisherAPI+adInteractiveState) ⇒ <code>Boolean</code>
    * [.adCompanions](#PublisherAPI+adCompanions) ⇒ <code>[Array.&lt;CompanionAd&gt;](#CompanionAd)</code>
    * [.adExtensions](#PublisherAPI+adExtensions) ⇒ <code>[Array.&lt;Extension&gt;](#Extension)</code>
    * [.initAdSlot(adBreak, environmentVars)](#PublisherAPI+initAdSlot) ⇒ <code>Promise</code>
    * [.startAdSlot()](#PublisherAPI+startAdSlot)
    * [.stopAdSlot()](#PublisherAPI+stopAdSlot)
    * [.skipAd()](#PublisherAPI+skipAd)
    * [.resize(boundingRectangle, viewMode)](#PublisherAPI+resize)
    * [.clickThrough(playerHandles)](#PublisherAPI+clickThrough) ⇒ <code>string</code>
    * [.pauseAd()](#PublisherAPI+pauseAd)
    * [.resumeAd()](#PublisherAPI+resumeAd)

<a name="new_PublisherAPI_new"></a>

### new PublisherAPI(playerProxy, config)

| Param | Type | Description |
| --- | --- | --- |
| playerProxy | <code>Object</code> | extended from [FacadeBase](FacadeBase) |
| config | <code>Object</code> | Global configuration |

<a name="PublisherAPI+adInfo"></a>

### publisherAPI.adInfo ⇒ <code>[AdInfo](#AdInfo)</code>
Combination of generic properties of all types of ads and custom properties that depend on VAST Extensions.

**Kind**: instance property of <code>[PublisherAPI](#PublisherAPI)</code>  
**Returns**: <code>[AdInfo](#AdInfo)</code> - Represents static information about the current ad  
<a name="PublisherAPI+adInteractiveState"></a>

### publisherAPI.adInteractiveState ⇒ <code>Boolean</code>
Returns whether the current ad is interactive (most likely by using __VPAID__) or not.

**Kind**: instance property of <code>[PublisherAPI](#PublisherAPI)</code>  
**Returns**: <code>Boolean</code> - True if the current ad has been specified as interactive  
<a name="PublisherAPI+adCompanions"></a>

### publisherAPI.adCompanions ⇒ <code>[Array.&lt;CompanionAd&gt;](#CompanionAd)</code>
The value of this property is an Array that provides ad companion details for each `<CompanionAd>` element.
The video player should request this value whenever it receives the `ON_COMPANIONS_DETECTED` event.

**Kind**: instance property of <code>[PublisherAPI](#PublisherAPI)</code>  
**Returns**: <code>[Array.&lt;CompanionAd&gt;](#CompanionAd)</code> - List of all companion ads  
<a name="PublisherAPI+adExtensions"></a>

### publisherAPI.adExtensions ⇒ <code>[Array.&lt;Extension&gt;](#Extension)</code>
The value of this property is an Array that provides ad extension details for the `<Extensions>` element.
The video player should request this value whenever it receives the **ON_EXTENSIONS_DETECTED** add-on event.

**Kind**: instance property of <code>[PublisherAPI](#PublisherAPI)</code>  
**Returns**: <code>[Array.&lt;Extension&gt;](#Extension)</code> - List of all extensions  
<a name="PublisherAPI+initAdSlot"></a>

### publisherAPI.initAdSlot(adBreak, environmentVars) ⇒ <code>Promise</code>
Invokes a commercial break by requesting the specified ad setup from the ad server.

**Kind**: instance method of <code>[PublisherAPI](#PublisherAPI)</code>  
**Returns**: <code>Promise</code> - Resolves if loading the ad manifests has been completed  

| Param | Type | Description |
| --- | --- | --- |
| adBreak | <code>[AdBreak](#AdBreak)</code> | Configuration for the upcoming ad break. |
| environmentVars | <code>[EnvironmentVars](#EnvironmentVars)</code> | Defines environment conditions for the upcoming ad break |

<a name="PublisherAPI+startAdSlot"></a>

### publisherAPI.startAdSlot()
Starts the ad break.
The add-on responds by sending an `ON_AD_SLOT_START` event notifying the video player the ad break is going to start.

**Kind**: instance method of <code>[PublisherAPI](#PublisherAPI)</code>  
<a name="PublisherAPI+stopAdSlot"></a>

### publisherAPI.stopAdSlot()
Stops a running ad break.
The add-on responds by sending an `ON_AD_SLOT_COMPLETE` event notifying the video player it has closed and cleaned up
ad resources. Also the content of the video player has been reseted.

**Kind**: instance method of <code>[PublisherAPI](#PublisherAPI)</code>  
<a name="PublisherAPI+skipAd"></a>

### publisherAPI.skipAd()
Skips (stops) a running single ad
The add-on respondes by sending the `ON_AD_SKIPPED` event notifying the video player it has closed and cleaned up
a single ad.

_Note: The add-on does proceed with the next ad. Canceling the whole ad break requires calling `stopAdSlot()` instead.

**Kind**: instance method of <code>[PublisherAPI](#PublisherAPI)</code>  
<a name="PublisherAPI+resize"></a>

### publisherAPI.resize(boundingRectangle, viewMode)
Following a resize of the video player, the video player calls `resize()` to allow the add-on
to scale and reposition itself within the display area. The add-on responds by sending an `ON_AD_SIZE_CHANGED` event.

**Kind**: instance method of <code>[PublisherAPI](#PublisherAPI)</code>  

| Param | Type | Description |
| --- | --- | --- |
| boundingRectangle | <code>Rectangle</code> | The video content display as a Rectangle {width, height, top, left} |
| viewMode | <code>string</code> | Current viewing mode (normal, fullscreen, thumbnail, dynamic) |

<a name="PublisherAPI+clickThrough"></a>

### publisherAPI.clickThrough(playerHandles) ⇒ <code>string</code>
Following a click on the ad, the video player calls `clickThrough()` to allow the add-on
to request the advertisers landing page and call the ClickThru tracking requests.

**Kind**: instance method of <code>[PublisherAPI](#PublisherAPI)</code>  
**Returns**: <code>string</code> - The landing page URL.  

| Param | Type | Description |
| --- | --- | --- |
| playerHandles | <code>Boolean</code> | Whether the player takes responsibility for opening the landing page URL. Defaulting to `false` if omitted. |

<a name="PublisherAPI+pauseAd"></a>

### publisherAPI.pauseAd()
Pauses the current ad break. The add-on responds by sending the `ON_AD_PAUSED` event.

**Kind**: instance method of <code>[PublisherAPI](#PublisherAPI)</code>  
<a name="PublisherAPI+resumeAd"></a>

### publisherAPI.resumeAd()
Resumes the current ad break. The add-on responds by sending the `ON_AD_PLAYING` event.

**Kind**: instance method of <code>[PublisherAPI](#PublisherAPI)</code>  
<a name="AdBreak"></a>

## AdBreak : <code>Object</code>
Definition of the upcoming ad slot.

**Kind**: global typedef  
**Properties**

| Name | Type | Description |
| --- | --- | --- |
| tag | <code>string</code> | AdRequest URL |
| opener | <code>string</code> |  |
| bumper | <code>string</code> |  |
| closer | <code>string</code> |  |

<a name="EnvironmentVars"></a>

## EnvironmentVars : <code>Object</code>
Used for passing implementation-specific runtime variables.

**Kind**: global typedef  
**Properties**

| Name | Type | Description |
| --- | --- | --- |
| desiredBitrate | <code>number</code> | Indicates the desired bitrate in kilobits per second (kbps). The player uses this information to select Mediafiles with an appropriate bitrate. Defaulting to `null`. |
| desiredMimeTypes | <code>Array</code> | Declaration of accepted media types. Defaulting to types that the browser eventually is able to play. Types must be compliant with the [IANA Media Type standard](https://www.iana.org/assignments/media-types/media-types.xhtml) |
| deviceType | <code>string</code> | Can be either `mobile`, `tablet`, `desktop` or `tv`. Defaulting to `null`. |
| deviceScreenSize | <code>Dimension</code> | Maximum size we can achieve when entering fullscreen. |
| networkReachability | <code>string</code> | Can be either `wwan`, `wifi` or `unreachable`. Defaulting to `null`. |
| vastMacroValues | <code>Object</code> | as defined by the VAST 4.1 specification. |

<a name="Wrapper"></a>

## Wrapper : <code>Array</code>
List of URLs that have been requested during a chain of ad server requests.

**Kind**: global typedef  
<a name="UniversalAdID"></a>

## UniversalAdID : <code>Object</code>
A unique creative ID for the ad across multiple systems.

**Kind**: global typedef  
**Properties**

| Name | Type | Description |
| --- | --- | --- |
| idRegistry | <code>string</code> | A string used to identify the URL for the registry website where the unique creative ID is cataloged. Defaulting to `unknown`. |
| idValue | <code>string</code> | A string identifying the unique creative identifier. Defaulting to `unknown`. |

<a name="AdInfo"></a>

## AdInfo : <code>Object</code>
Collection of data that describes the current video ad.

**Kind**: global typedef  
**Properties**

| Name | Type | Description |
| --- | --- | --- |
| adId | <code>string</code> | Value of the `id` attribute from the `VAST > Ad` node |
| title | <code>string</code> | Value of the `VAST > Ad > AdTitle` node |
| variant | <code>string</code> | Ad variant, depending on the current schedule and VAST manifest. |
| skippable | <code>Boolean</code> | The default value for this property is `false`. When the ad reaches a point where it can be skipped, the ad unit updates this property to true and sends the `ON_AD_SKIPPABLE_STATE_CHANGE` event. The video player can check this property at any time, but should always check it when the `ON_AD_SKIPPABLE_STATE_CHANGE` event is received. |
| currentClip | <code>number</code> | Index of the current ad, regardless of its variant. |
| totalClips | <code>number</code> | Total number of ads within the current ad break, regardless of variants. |
| currentCommercial | <code>number</code> | Index of the current ad of variant `COMMERCIAL`. Defaulting to -1 |
| totalCommercials | <code>number</code> | Total number of ads with variant `COMMERCIAL` within the current ad break |
| totalCommercialsDuration | <code>number</code> | Total duration of ads with variant `COMMERCIAL` within the current ad break |
| totalCommercialsCurrentTime | <code>number</code> | Current time of all ads with variant `COMMERCIAL` within the current ad break |
| duration | <code>number</code> | Total time of the current ad |
| currentTime | <code>number</code> | Current time of the current ad |
| wrapperTags | <code>[Array.&lt;Wrapper&gt;](#Wrapper)</code> | List of Wrapper URLs, starting with the initial request up to the last Wrapper before the Inline tag. |
| universalAdID | <code>[UniversalAdID](#UniversalAdID)</code> | A unique creative identifier that is maintained across different ad systems. |
| errorCode | <code>number</code> | Code according to [IAB VAST 4.0](https://www.iab.com/guidelines/digital-video-ad-serving-template-vast-4-0) Error Codes Table. Defaulting to '--' (no error). |

<a name="CompanionAd"></a>

## CompanionAd : <code>Object</code>
Secondary ads included in the VAST tag that accompany the video ad.

**Kind**: global typedef  
**Properties**

| Name | Type | Description |
| --- | --- | --- |
| type | <code>string</code> | Type of the companion creative resource. Can be either `StaticResource`, `IFrameResource` or `HTMLResource` |
| companionXML | <code>xml</code> | Full <CompanionAd> node. |

<a name="Extension"></a>

## Extension : <code>Object</code>
Custom XML element that extends the video ad.

**Kind**: global typedef  
**Properties**

| Name | Type | Description |
| --- | --- | --- |
| type | <code>string</code> | The MIME type of any code that might be included in the extension. Type should be compliant with the [IANA Media Type standard](https://www.iana.org/assignments/media-types/media-types.xhtml) |
| extensionXML | <code>xml</code> | Full <Extension> node. |

